# Contres
Contres command line interface - WIP

Contres is the command line interface for deploying a research 
project in a Gitlab environment following the CR guidelines. 
CR is short for continuous research (like contres), an outline 
of how to utilize gitlab CI runners to make research scripts 
reproducible and cloneable with one click.

A paper or guide will be distributed with this CLI once it left 
experimental stage.

## Installation

Please not that this tool might heavily change as it is still work in progress.

Install contres using pip

```bash
pip install contres
```

Then, there should be a cli available on your path called `contres`. 

```bash
contres -h
```

This guide will be extended with the next release.
